@@ -35,7 +35,7 @@ window.zerobin = {
         and all of them are executed in a timed continuation to give
         a change to the UI to respond.
     */
-    version: '0.1',
+    version: '0.1.1',
     encrypt: function(key, content, toBase64Callback,
                     compressCallback, encryptCallback, doneCallback) {
 
@@ -146,9 +146,9 @@ window.zerobin = {
 
   getFormatedTime: function(date){
     date = date || new Date();
-    var h = date.getHours();
-    var m = date.getMinutes();
-    var s = date.getSeconds();
+    var h = date.getHours(),
+        m = date.getMinutes(),
+        s = date.getSeconds();
     if (h < 10) {h = "0" + h;}
     if (m < 10) {m = "0" + m;}
     if (s < 10) {s = "0" + s;}
@@ -162,8 +162,8 @@ window.zerobin = {
   /** Return a reverse sorted list of all the keys in local storage that
       are prefixed with with the passed version (default being this lib
       version) */
-  getLocalStorageKeys: function(version){
-    version = 'zerobinV'  + (version || zerobin.version);
+  getLocalStorageKeys: function(){
+    var version = 'zerobinV0.1';
     var keys = [];
     for (var key in localStorage){
        if (key.indexOf(version) !== -1){
@@ -177,9 +177,9 @@ window.zerobin = {
 
   /** Get a tinyurl using JSONP */
   getTinyURL: function(longURL, success) {
-    var api = 'http://json-tinyurl.appspot.com/?url=';
+    var api = 'http://is.gd/create.php?format=json&url=';
     $.getJSON(api + encodeURIComponent(longURL) + '&callback=?', function(data){
-      success(data.tinyurl);
+      success(data.shorturl);
     });
   },
 
@@ -269,19 +269,19 @@ window.zerobin = {
 
   getPasteId: function(url){
     var loc = url ? zerobin.parseUrl(url) : window.location;
-    return loc.pathname.replace(/\/|paste/g, '').replace(/\?.*$/, '');
+    return loc.pathname.replace(/\/|paste/g, '');
   },
 
   getPasteKey: function(url){
     var loc = url ? zerobin.parseUrl(url) : window.location;
-    return loc.hash.replace('#', '').replace(/\?.*$/, '');
+    return loc.hash.replace('#', '').replace(/(\?|&).*$/, '');
   },
 
   /** Return the paste content stripted from any code coloration */
   getPasteContent: function(){
     var copy = '' ;
     $("#paste-content li").each(function(index) {
-      copy = copy + $(this).text() + '\n';
+      copy = copy + $(this).text().replace(/[\u00a0]+/g, ' ') + '\n';
     });
     return copy;
   },
@@ -302,7 +302,6 @@ window.zerobin = {
   },
   /** Create a message, style it and insert it in the alert box */
   message: function(type, message, title, flush, callback) {
-
     $(window).scrollTop(0);
 
     if (flush) {$('.alert-'+type).remove();}
@@ -323,6 +322,28 @@ window.zerobin = {
     var bar = {container: $container, elem: $container.find('.bar')};
     bar.set =  function(text, rate){bar.elem.text(text).css('width', rate);};
     return bar;
+  },
+
+  /** Return an integer ranking the probability this text is any kind of
+      source code. */
+  isCode: function(text){
+
+    var code_chars = /[A-Z]{3}[A-Z]+|\.[a-z]|[=:<>{}\[\]$_'"&]| {2}|\t/g;
+    var comment = /(\/\*|\/\/|#|;).*$/g;
+
+    var total = 0;
+    var size = 0;
+    text = text.split('\n');
+    for (var i = 0; i < text.length; i++) {
+        var line = text[i];
+        size += line.length;
+        var match = line.replace(comment, '').match(code_chars);
+        if (match) {
+            total += match.length;
+        }
+    }
+
+    return total * 1000 / size;
   }
 };
 
@@ -435,6 +456,7 @@ $('.btn-primary').live("click", function(e){
 var content = $('#paste-content').text().trim();
 var key = zerobin.getPasteKey();
 var error = false;
+
 if (content && key) {
 
   /* Load the lib for visual canvas, create one from the paste id and
@@ -476,7 +498,6 @@ if (content && key) {
 
       /* Decrypted content goes back to initial container*/
       $('#paste-content').text(content);
-      content = '';
 
       bar.set('Code coloration...', '95%');
 
@@ -522,13 +543,23 @@ if (content && key) {
 
         /* Remap the message close handler to include the clipboard
            flash reposition */
-        $(".close").off().live('click', function(e){
+        $(".close").die().live('click', function(e){
           e.preventDefault();
           $(this).parent().fadeOut(reposition);
         });
 
         /** Syntaxic coloration */
-        prettyPrint();
+
+        if (zerobin.isCode(content) > 100){
+           $('#paste-content').addClass('linenums');
+          prettyPrint();
+        } else {
+          zerobin.message('info',
+                          "The paste didn't not seem to be code, so it " +
+                          "was not colorized. " +
+                          "<a id='force-coloration' href='#'>Force coloration</a>",
+                          '', false, reposition);
+        }
 
         /* Class to switch to paste content style with coloration done */
         $('#paste-content').addClass('done');
@@ -538,6 +569,7 @@ if (content && key) {
         bar.container.hide();
 
         $form.prop('disabled', false);
+        content = '';
 
       }, 250);
 
@@ -599,7 +631,10 @@ if (zerobin.support.localStorage){
         // does redirect to the page
         if (paste.link.replace(/#[^#]+/, '') === window.location.pathname){
           $li.addClass('active');
-          $link.click(function(){window.location.reload();});
+          $link.click(function(){
+            window.location = $link.attr('href');
+            window.location.reload();
+          });
         }
 
       });
@@ -674,8 +709,40 @@ $('.email-link').each(function(i, elem){
 
 });
 
+/* Show the page using javascript. Non js enabled browser will see an
+   error message */
+$('#wrap-content').each(function(i, elem){
+    $(elem).show();
+});
+
+/* Remove expired pasted from history */
+if (zerobin.support.history && zerobin.paste_not_found){
+  var paste_id = zerobin.getPasteId();
+  var keys = zerobin.getLocalStorageKeys();
+  $.each(keys, function(i, key){
+     if (localStorage[key].indexOf(paste_id) !== -1){
+        localStorage.removeItem(key);
+        return false;
+     }
+  });
+}
+
+
+/* Force text coloration when clickin on link */
+$("#force-coloration").live("click", function(e) {
+  e.preventDefault();
+  $('#paste-content').addClass('linenums');
+  $(this).die(e).text('Applying coloration');
+  prettyPrint();
+  $(this).remove();
+});
+
+/* Send the paste by email */
+var emailLink = 'mailto:friend@example.com?body=' + window.location;
+$('#email-link').attr('href', emailLink);
+
 
 
 }); /* End of "document ready" jquery callback */
 
-})(); /* End of self executing function */
\ No newline at end of file
+})(); /* End of self executing function */
